@@ -64,6 +64,9 @@ class SheinProductSkc(Base):
     created_at = Column(DateTime, default=datetime.now, comment='创建时间')
     updated_at = Column(DateTime, default=datetime.now, onupdate=datetime.now, comment='更新时间')
 
+    # 用户备注字段（供后续web界面使用）
+    user_notes = Column(Text, nullable=True, comment='用户备注')
+
     # 定义索引
     __table_args__ = (
         Index('ix_skc_id', 'skc_id'),
@@ -108,6 +111,7 @@ class SheinProductSku(Base):
     price = Column(DECIMAL(10, 2), nullable=True, comment='价格')
     erp_cost_price = Column(DECIMAL(10, 2), nullable=True, comment='ERP成本价')
     erp_supplier_name = Column(String(100), nullable=True, comment='ERP默认供货商')
+    erp_stock = Column(Integer, nullable=True, comment='ERP库存')
 
     # 时间戳
     created_at = Column(DateTime, default=datetime.now, comment='创建时间')
@@ -218,10 +222,10 @@ class SheinProductManager:
         session = self.Session()
         try:
             for data in data_list:
-                
+
                 # 处理SKC数据
                 skc_record = self._upsert_skc_data(session, data)
-                
+
                 # 处理SKU数据
                 for sku_data in data.get('skuList', []):
                     sku_data['local_skc_id'] = skc_record.id
@@ -319,6 +323,7 @@ class SheinProductManager:
             existing_sku.price = sku_data.get('price')
             existing_sku.erp_cost_price = sku_data.get('erp_cost_price')
             existing_sku.erp_supplier_name = sku_data.get('erp_supplier_name')
+            existing_sku.erp_stock = sku_data.get('erp_stock')
             existing_sku.updated_at = datetime.now()
         else:
             # 插入新记录
@@ -473,4 +478,7 @@ def example_usage2():
 
 if __name__ == "__main__":
     pass
-    # example_usage()
\ No newline at end of file
+    database_url = "mysql+pymysql://root:123wyk@localhost:3306/lz"
+    manager = SheinProductManager(database_url)
+    manager.create_tables()
+    # example_usage()
