@@ -376,7 +376,7 @@ class ZiniaoTaskManager:
                     return
 
                 # 打开店铺
-                print(f"=====打开店铺：{store_name}=====")
+                print(f"=====打开店铺：{store_name},{browser_id},{store_username}=====")
                 ret_json = self.browser.open_store(store_id)
                 print(ret_json)
                 store_id = ret_json.get("browserOauth") or ret_json.get("browserId")
